==> aroundme_0_6_7.tar.tgz: aroundme_0_6_7/aroundme/language/1/barnraiser_01/grp_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//section titles
$lang['hdr_group'] = 							"group";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_apply'] = 							"apply";


//MENU
$lang['menu_membership'] = 						"membership";


//A HREF TAGS (links)
$lang['href_edit_group'] = 						"edit group";
$lang['href_edit_rules'] = 						"edit group rules";
$lang['href_edit_categories'] = 				"edit group categories";
$lang['href_edit_this'] = 						"edit this";
$lang['href_latest_blog'] = 					"latest blog";
$lang['href_blog_list'] = 						"list";
$lang['href_join'] = 							"join this group!";


//ERRORS
$lang['err_no_schedule_items'] = 				"Sorry, no group schedule items available.";
$lang['err_no_groups'] = 						"Sorry, no groups available.";
$lang['err_no_library'] = 						"Sorry, no library documents available.";
$lang['err_no_members'] = 						"Sorry, no members available.";
$lang['err_no_member_statistics'] = 			"Sorry, this person has no group statistics available.";
$lang['err_no_search_results'] = 				"Sorry, nothing found. Please try another search.";
$lang['err_no_statistics'] = 					"Sorry, this group has no statistics available.";
$lang['err_no_subjects'] = 						"Sorry, no discussion subjects available.";
$lang['err_no_comments'] = 						"Sorry, no comments available.";
$lang['err_no_file'] = 							"Sorry, file available.";
$lang['err_no_member'] = 						"Sorry, this person is not a member of this group.";
$lang['err_no_blogs'] = 						"Sorry, no blogs available.";
$lang['err_no_topics'] = 						"Sorry, no Topics available.";
$lang['err_no_polls'] = 						"Sorry, no Polls available.";
$lang['err_no_tasks'] = 						"Sorry, no group tasks available.";


//SUBMIT BUTTONS
$lang['sub_delete'] = 							"delete";
$lang['sub_search'] = 							"search";
$lang['sub_update'] = 							"update";
$lang['sub_preview'] = 							"preview";
$lang['sub_add'] = 								"add";


//BODY TEXT
$lang['txt_category'] = 						"categories";
$lang['txt_votes'] = 							"votes";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_group_language'] = 					"language";
$lang['txt_group_type'] = 						"type";
$lang['txt_membership_status'] = 				"status";
$lang['txt_rec_age'] = 							"age";
$lang['txt_age_all'] = 							"all";
$lang['txt_age_from'] = 						"from";
$lang['txt_age_upto'] = 						"upto";
$lang['txt_recommended_age'] = 					"recommended age";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_locked'] = 							"locked";
$lang['txt_from'] =								"From";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the group. Reply in group language only.";
$lang['txt_search'] = 							"group search";

?>

==> aroundme_0_6_9.tar.tgz: aroundme_0_6_9/aroundme/language/1/barnraiser_01/grp_common.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//section titles
$lang['hdr_group'] = 							"group";
$lang['hdr_comments'] = 						"comments";
$lang['hdr_apply'] = 							"apply";


//MENU
$lang['menu_membership'] = 						"membership";


//A HREF TAGS (links)
$lang['href_edit_group'] = 						"edit group";
$lang['href_edit_rules'] = 						"edit group rules";
$lang['href_edit_categories'] = 				"edit group categories";
$lang['href_edit_this'] = 						"edit this";
$lang['href_latest_blog'] = 					"latest blog";
$lang['href_blog_list'] = 						"list";
$lang['href_join'] = 							"join this group!";


//ERRORS
$lang['err_no_schedule_items'] = 				"Sorry, no group schedule items available.";
$lang['err_no_groups'] = 						"Sorry, no groups available.";
$lang['err_no_library'] = 						"Sorry, no library documents available.";
$lang['err_no_members'] = 						"Sorry, no members available.";
$lang['err_no_member_statistics'] = 			"Sorry, this person has no group statistics available.";
$lang['err_no_search_results'] = 				"Sorry, nothing found. Please try another search.";
$lang['err_no_statistics'] = 					"Sorry, this group has no statistics available.";
$lang['err_no_subjects'] = 						"Sorry, no discussion subjects available.";
$lang['err_no_comments'] = 						"Sorry, no comments available.";
$lang['err_no_file'] = 							"Sorry, file available.";
$lang['err_no_member'] = 						"Sorry, this person is not a member of this group.";
$lang['err_no_blogs'] = 						"Sorry, no group blogs available.";
$lang['err_no_topics'] = 						"Sorry, no group topics available.";
$lang['err_no_polls'] = 						"Sorry, no group polls available.";
$lang['err_no_tasks'] = 						"Sorry, no group tasks available.";
$lang['err_no_quizzes'] = 						"Sorry, no group quizzes available.";


//SUBMIT BUTTONS
$lang['sub_delete'] = 							"delete";
$lang['sub_search'] = 							"search";
$lang['sub_update'] = 							"update";
$lang['sub_preview'] = 							"preview";
$lang['sub_add'] = 								"add";


//BODY TEXT
$lang['txt_category'] = 						"categories";
$lang['txt_votes'] = 							"votes";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_group_language'] = 					"language";
$lang['txt_group_type'] = 						"type";
$lang['txt_membership_status'] = 				"status";
$lang['txt_rec_age'] = 							"age";
$lang['txt_age_all'] = 							"all";
$lang['txt_age_from'] = 						"from";
$lang['txt_age_upto'] = 						"upto";
$lang['txt_recommended_age'] = 					"recommended age";
$lang['txt_hidden'] = 							"hidden";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_locked'] = 							"locked";
$lang['txt_from'] =								"From";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the group. Reply in group language only.";
$lang['txt_search'] = 							"group search";

?>
